@@ -2,6 +2,8 @@
 
 ;;; Code:
 
+(autoload 'custom-add-loads "cus-load")
+
 (custom-add-loads 'cperl '("cperl-mode"))
 (custom-add-loads 'prolog '("prolog"))
 (custom-add-loads 'pascal '("pascal"))
@@ -11,10 +13,12 @@
 (custom-add-loads 'fortran-indent '("fortran"))
 (custom-add-loads 'compilation-remote '("mode-compile"))
 (custom-add-loads 'lisp-indent '("cl-indent"))
-(custom-add-loads 'tools '("make-mode" "mode-compile"))
+(custom-add-loads 'tools '("diff-mode" "make-mode" "mode-compile"))
 (custom-add-loads 'cperl-speed '("cperl-mode"))
 (custom-add-loads 'compile-perl '("mode-compile"))
+(custom-add-loads 'diff-mode '("diff-mode"))
 (custom-add-loads 'lisp '("cl-indent" "mode-compile"))
+(custom-add-loads 'diff '("diff-mode"))
 (custom-add-loads 'compile-c '("mode-compile"))
 (custom-add-loads 'compilation-frame '("mode-compile"))
 (custom-add-loads 'cperl-affected-by-hairy '("cperl-mode"))
